#include <QGuiApplication>
#include <QQmlContext>
#include <QDebug>
#include <QQuickView>

static QString description()
{
    QString t = QT_VERSION_STR;
#if QT_VERSION >= 0x050000
    t += QLatin1Char(' ') + QGuiApplication::platformName();
#endif
    return t;
}

class FramelessWindow : public QQuickView
{
    Q_OBJECT
public:
    FramelessWindow();

private slots:
    void slotWindowStateChanged(Qt::WindowState windowState)
    {
        qDebug() << __FUNCTION__ << windowState;
    }
};

FramelessWindow::FramelessWindow()
{
    connect(this, &QWindow::windowStateChanged, this, &FramelessWindow::slotWindowStateChanged);
    rootContext()->setContextProperty("_window", this);
    setResizeMode(QQuickView::SizeRootObjectToView);
    setSource(QUrl("qrc:/main.qml"));
}

int main(int argc, char *argv[])
{
    QGuiApplication app(argc, argv);
    QStringList args = app.arguments();
    args.pop_front();

    QString t = description();
    qDebug() << t << args;

    FramelessWindow window;
    window.setTitle(t);
    if (args.contains("-m"))
        window.showMaximized();
    else
        window.show();

    return app.exec();
}

#include "main.moc"
